@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.c,v 1.52 2002/08/21 14:03:50 bazsi Exp $
+ * $Id: affile.c,v 1.53 2002/09/27 09:11:33 bazsi Exp $
  *
  ***************************************************************************/
  
@@ -859,7 +859,7 @@ expand_macros(struct syslog_config *cfg, struct ol_string *template, int templat
 		{ "SOURCEIP", M_SOURCE_IP }
 	};
 	char format[cfg->log_msg_size + 1], *format_ptr = format;
-	int left = sizeof(format);
+	int left = sizeof(format) - 1;
 	int i, j;
 
 	i = 0;
@@ -888,6 +888,7 @@ expand_macros(struct syslog_config *cfg, struct ol_string *template, int templat
 			*format_ptr = template->data[i];
 			format_ptr++;
 			i++;
+			left--;
 		}
 	}
 	*format_ptr = 0;
