@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afinet.c,v 1.19 2002/07/18 13:18:01 bazsi Exp $
+ * $Id: afinet.c,v 1.20 2002/08/21 14:03:50 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -89,13 +89,13 @@ do_init_afinet_source_connection(struct log_handler *c,
 		notice("AF_INET client connected from %S, port %i\n", 
 		       inet->ip, inet->port);
 		io_read(self->client, 
-			make_log_reader(0, NULL, cfg->log_msg_size, 0, c), 
+			make_log_reader(0, NULL, cfg->log_msg_size, 0, cfg->check_hostname ? LF_CHECK_HOSTNAME : 0, c), 
 			make_afsocket_source_close_callback(self));
 	}
 	else {
 		/* SOCK_DGRAM */
 		io_read(self->client, 
-			make_log_reader(1, NULL, cfg->log_msg_size, 0, c), 
+			make_log_reader(1, NULL, cfg->log_msg_size, 0, cfg->check_hostname ? LF_CHECK_HOSTNAME : 0, c), 
 			make_afsocket_source_close_callback(self));
 	}
 	
