@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: log.c,v 1.26 2002/04/26 09:43:54 bazsi Exp $
+ * $Id: log.c,v 1.27 2002/08/21 14:03:50 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -161,6 +161,15 @@ static void parse_log_msg(struct log_info *lm, UINT32 length, UINT8 *data, UINT8
 
 			while (left && *src != ' ' && *src != ':' 
 			       && *src != '[') {
+				if (lm->flags & LF_CHECK_HOSTNAME &&
+				    !((*src >= 'A' && *src <= 'Z') ||
+				      (*src >= 'a' && *src <= 'z') ||
+				      (*src >= '0' && *src <= '9') ||
+				      *src == '-' || *src == '_' ||
+				      *src == '.' || *src == ':' ||
+				      *src == '@' || *src == '/')) {
+					break;
+				}
 		 		src++;
 				left--;
 			}
@@ -256,11 +265,12 @@ void log_info_free(struct log_info *msg)
 	}
 }
 
-struct log_info *make_log_info(UINT32 length, UINT8 *msg, UINT8 *prefix)
+struct log_info *make_log_info(UINT32 length, UINT8 *msg, UINT8 *prefix, UINT32 flags)
 {
 	struct log_info *self;
 
 	NEW_SPACE(self);
+	self->flags = flags & LF_USER_FLAGS;
   	parse_log_msg(self, length, msg, prefix);
 	self->use_cnt = 1;
   	self->recvd = time(NULL);
