@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: main.c,v 1.43 2002/08/21 14:03:50 bazsi Exp $
+ * $Id: main.c,v 1.46 2002/10/14 08:24:05 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -41,6 +41,7 @@
 #include <getopt.h>
 #include <grp.h>
 #include <pwd.h>
+#include <resolv.h>
 
 #include "main.c.x"
 
@@ -134,6 +135,11 @@ static void do_report_stats(struct callback *c)
 	io_callout(&self->backend->super, self->timeout, &self->super);
 }
 
+static void do_flush_wakeup(struct callback *c)
+{
+	;
+}
+
 /* CLASS:
    (class
      (name syslog_backend)
@@ -215,13 +221,19 @@ int main_loop(struct syslog_backend *backend)
 		}
 
 		if (sigtermrecvd) {
+			static struct callback wakeup = 
+				{ STATIC_HEADER, do_flush_wakeup };
+			
 			notice("syslog-ng version %z going down\n", VERSION);
 			exit_main_loop = 1;
+			io_callout(&backend->super, 1, &wakeup);
 		}
 		if (sighuprecvd) {
 			sighuprecvd = 0;
 			if (!backend->super.reloading) {
-
+#if HAVE_RES_INIT
+				res_init();
+#endif
 				notice("SIGHUP received, restarting syslog-ng\n");
 				if (!debug_flag) {
 					set_error_stream(2, 0);
@@ -381,7 +393,8 @@ int main(int argc, char **argv)
 	int opt;
 	int wakeup_fd = -1;
 	char *chroot_dir = NULL;
-	int uid = 0, gid = 0;
+	uid_t uid = 0;
+	gid_t gid = 0;
 
 	NEW(syslog_backend, backend);
 	struct option syslog_ng_options[] = {
@@ -493,6 +506,7 @@ int main(int argc, char **argv)
 	}
 
 	if (!debug_flag) {
+		set_internal_cfg(backend->configuration);
 		set_error_internal();
 	}
 	else {
